## $Id: payments.py 7599 2012-02-07 11:30:00Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""
Student payment components.
"""
import grok
from zope.component.interfaces import IFactory
from zope.interface import implementedBy
from waeup.sirp.students.interfaces import (
    IStudentPaymentsContainer, IStudentNavigation, IStudentOnlinePayment)
from waeup.sirp.payments import PaymentsContainer, OnlinePayment
from waeup.sirp.utils.helpers import attrs_to_fields

class StudentPaymentsContainer(PaymentsContainer):
    """This is a container for student payments.
    """
    grok.implements(IStudentPaymentsContainer, IStudentNavigation)
    grok.provides(IStudentPaymentsContainer)

    def __init__(self):
        super(StudentPaymentsContainer, self).__init__()
        return

    def getStudent(self):
        return self.__parent__

StudentPaymentsContainer = attrs_to_fields(StudentPaymentsContainer)

class StudentOnlinePayment(OnlinePayment):
    """This is an online payment.
    """
    grok.implements(IStudentOnlinePayment, IStudentNavigation)
    grok.provides(IStudentOnlinePayment)

    def __init__(self):
        super(StudentOnlinePayment, self).__init__()
        return

    def getStudent(self):
        return self.__parent__.__parent__

StudentOnlinePayment = attrs_to_fields(StudentOnlinePayment)

# Student online payments must be importable. So we might need a factory.
class StudentOnlinePaymentFactory(grok.GlobalUtility):
    """A factory for student online payments.
    """
    grok.implements(IFactory)
    grok.name(u'waeup.StudentOnlinePayment')
    title = u"Create a new online payment.",
    description = u"This factory instantiates new online payment instances."

    def __call__(self, *args, **kw):
        return StudentOnlinePayment()

    def getInterfaces(self):
        return implementedBy(StudentOnlinePayment)